@@ -1,12 +1,25 @@
 from django.db import models
-
+from django.utils.six import with_metaclass
 import form_fields
 import widgets
+import json
 
-class OpeningHoursField(models.Field):
+class OpeningHoursField(with_metaclass(models.SubfieldBase, models.Field)):
     def get_internal_type(self):
         return "TextField"
 
+    def to_python(self, value):
+        if type(value) == str or type(value) == unicode:
+            return json.loads(value)
+        else:
+            return value
+
+    def get_prep_value(self, value):
+        if type(value) != str or type(value) != unicode:
+            return json.dumps(value)
+        else:
+            return value
+
     def formfield(self, **kwargs):
         defaults = {
             'form_class': form_fields.OpeningHoursField,
@@ -19,4 +32,4 @@ class OpeningHoursField(models.Field):
         from south.modelsinspector import introspector
         field_class = "django.db.models.fields.TextField"
         args, kwargs = introspector(self)
-        return (field_class, args, kwargs)
\ No newline at end of file
+        return (field_class, args, kwargs)
