@@ -1,3 +1,5 @@
+import json
+
 from django.forms.widgets import Widget
 
 from django.template import loader
@@ -12,7 +14,7 @@ class OpeningHoursWidget(Widget):
         if not value:
             value = '{"first_day": "mo", "mo": [], "tu":[], "we":[], "th":[], "fr":[], "sa":[], "su":[], "mo_note": "", "tu_note": "", "we_note":"", "th_note":"", "fr_note":"", "sa_note":"", "su_note":"" }'
         return mark_safe(loader.render_to_string(self.template, {
-            "value": value,
+            "value": json.dumps(value),
             "name": name,
             "STATIC_URL": settings.STATIC_URL,
-        }))
+        }))
\ No newline at end of file
